@@ -4,7 +4,7 @@ Python A2A - Agent-to-Agent Protocol
 A Python library for implementing Google's Agent-to-Agent (A2A) protocol.
 """
 
-__version__ = "0.5.2"
+__version__ = "0.5.8"
 
 # Setup feature flags
 import sys
@@ -21,7 +21,7 @@ from .exceptions import (
     A2AValidationError,
     A2AAuthenticationError,
     A2AConfigurationError,
-    A2AStreamingError
+    A2AStreamingError,
 )
 
 # All core models - these should be available with basic install
@@ -35,7 +35,7 @@ from .models.content import (
     FunctionCallContent,
     FunctionResponseContent,
     ErrorContent,
-    Metadata
+    Metadata,
 )
 from .models.agent import AgentCard, AgentSkill
 from .models.task import Task, TaskStatus, TaskState
@@ -52,18 +52,27 @@ from .server.base import BaseA2AServer
 from .server.a2a_server import A2AServer
 from .server.http import run_server
 
+# Agent discovery functionality
+from .discovery import (
+    AgentRegistry,
+    run_registry,
+    DiscoveryClient,
+    enable_discovery,
+    RegistryAgent,
+)
+
 # Utility functions
 from .utils.formatting import (
     format_message_as_text,
     format_conversation_as_text,
     pretty_print_message,
-    pretty_print_conversation
+    pretty_print_conversation,
 )
 from .utils.validation import (
     validate_message,
     validate_conversation,
     is_valid_message,
-    is_valid_conversation
+    is_valid_conversation,
 )
 from .utils.conversion import (
     create_text_message,
@@ -71,7 +80,7 @@ from .utils.conversion import (
     create_function_response,
     create_error_message,
     format_function_params,
-    conversation_to_messages
+    conversation_to_messages,
 )
 from .utils.decorators import skill, agent
 
@@ -87,7 +96,7 @@ from .workflow import (
     ConditionStep,
     ParallelStep,
     ParallelBuilder,
-    StepType
+    StepType,
 )
 
 # MCP integration
@@ -97,7 +106,6 @@ from .mcp.client import (
     MCPConnectionError,
     MCPTimeoutError,
     MCPToolError,
-    MCPTools
 )
 from .mcp.agent import MCPEnabledAgent
 from .mcp.fastmcp import (
@@ -107,12 +115,9 @@ from .mcp.fastmcp import (
     error_response,
     image_response,
     multi_content_response,
-    ContentType as MCPContentType
-)
-from .mcp.integration import (
-    FastMCPAgent,
-    A2AMCPAgent
+    ContentType as MCPContentType,
 )
+from .mcp.integration import FastMCPAgent, A2AMCPAgent
 from .mcp.proxy import create_proxy_server
 from .mcp.transport import create_fastapi_app
 
@@ -121,7 +126,7 @@ from .langchain import (
     to_a2a_server,
     to_langchain_agent,
     to_mcp_server,
-    to_langchain_tool
+    to_langchain_tool,
 )
 from .langchain.exceptions import (
     LangChainIntegrationError,
@@ -129,15 +134,25 @@ from .langchain.exceptions import (
     LangChainToolConversionError,
     MCPToolConversionError,
     LangChainAgentConversionError,
-    A2AAgentConversionError
+    A2AAgentConversionError,
+)
+
+HAS_LANGCHAIN = (
+    importlib.util.find_spec("langchain") is not None
+    or importlib.util.find_spec("langchain_core") is not None
 )
-HAS_LANGCHAIN = importlib.util.find_spec("langchain") is not None or importlib.util.find_spec("langchain_core") is not None
 
 # Optional integration with LLM providers
 # These might not be available if the specific provider packages are not installed
 try:
-    from .client.llm import OpenAIA2AClient, AnthropicA2AClient
-    from .server.llm import OpenAIA2AServer, AnthropicA2AServer, BedrockA2AServer
+    from .client.llm import OpenAIA2AClient, OllamaA2AClient, AnthropicA2AClient
+    from .server.llm import (
+        OpenAIA2AServer,
+        OllamaA2AServer,
+        AnthropicA2AServer,
+        BedrockA2AServer,
+    )
+
     HAS_LLM_CLIENTS = True
     HAS_LLM_SERVERS = True
 except ImportError:
@@ -147,6 +162,7 @@ except ImportError:
 # Optional doc generation
 try:
     from .docs import generate_a2a_docs, generate_html_docs
+
     HAS_DOCS = True
 except ImportError:
     HAS_DOCS = False
@@ -154,144 +170,154 @@ except ImportError:
 # Optional CLI
 try:
     from .cli import main as cli_main
+
     HAS_CLI = True
 except ImportError:
     HAS_CLI = False
 
+# Agent Flow import - optional but integrated by default
+try:
+    from .agent_flow import models, engine, server, storage
+
+    HAS_AGENT_FLOW_IMPORT = True
+except ImportError:
+    HAS_AGENT_FLOW_IMPORT = False
+
 # Set feature flags (all core features should be True)
 HAS_MODELS = True
 HAS_ADVANCED_MODELS = True
 HAS_CLIENT_BASE = True
 HAS_HTTP_CLIENT = True
-HAS_ADVANCED_CLIENTS = True 
+HAS_ADVANCED_CLIENTS = True
 HAS_SERVER_BASE = True
 HAS_SERVER = True
 HAS_UTILS = True
 HAS_DECORATORS = True
 HAS_WORKFLOW = True
 HAS_MCP = True
+HAS_DISCOVERY = True  # Agent discovery
 HAS_LANGCHAIN_INTEGRATION = True  # Always True since we provide the interface
+HAS_AGENT_FLOW = True  # Agent Flow UI and workflow editor
 
 # Define __all__ for explicit exports
 __all__ = [
     # Version
-    '__version__',
-
+    "__version__",
     # Exceptions
-    'A2AError',
-    'A2AImportError',
-    'A2AConnectionError',
-    'A2AResponseError',
-    'A2ARequestError',
-    'A2AValidationError',
-    'A2AAuthenticationError',
-    'A2AConfigurationError',
-    'A2AStreamingError',
-    
+    "A2AError",
+    "A2AImportError",
+    "A2AConnectionError",
+    "A2AResponseError",
+    "A2ARequestError",
+    "A2AValidationError",
+    "A2AAuthenticationError",
+    "A2AConfigurationError",
+    "A2AStreamingError",
     # Models
-    'BaseModel',
-    'Message',
-    'MessageRole',
-    'Conversation',
-    'ContentType',
-    'TextContent',
-    'FunctionParameter',
-    'FunctionCallContent',
-    'FunctionResponseContent',
-    'ErrorContent',
-    'Metadata',
-    'AgentCard',
-    'AgentSkill',
-    'Task',
-    'TaskStatus',
-    'TaskState',
-    
+    "BaseModel",
+    "Message",
+    "MessageRole",
+    "Conversation",
+    "ContentType",
+    "TextContent",
+    "FunctionParameter",
+    "FunctionCallContent",
+    "FunctionResponseContent",
+    "ErrorContent",
+    "Metadata",
+    "AgentCard",
+    "AgentSkill",
+    "Task",
+    "TaskStatus",
+    "TaskState",
     # Client
-    'BaseA2AClient',
-    'A2AClient',
-    'AgentNetwork',
-    'AIAgentRouter',
-    'StreamingClient',
-    
+    "BaseA2AClient",
+    "A2AClient",
+    "AgentNetwork",
+    "AIAgentRouter",
+    "StreamingClient",
     # Server
-    'BaseA2AServer',
-    'A2AServer',
-    'run_server',
-    
+    "BaseA2AServer",
+    "A2AServer",
+    "run_server",
+    # Discovery
+    "AgentRegistry",
+    "run_registry",
+    "DiscoveryClient",
+    "enable_discovery",
+    "RegistryAgent",
     # Utilities
-    'format_message_as_text',
-    'format_conversation_as_text',
-    'pretty_print_message',
-    'pretty_print_conversation',
-    'validate_message',
-    'validate_conversation',
-    'is_valid_message',
-    'is_valid_conversation',
-    'create_text_message',
-    'create_function_call',
-    'create_function_response',
-    'create_error_message',
-    'format_function_params',
-    'conversation_to_messages',
-    'skill',
-    'agent',
-    
+    "format_message_as_text",
+    "format_conversation_as_text",
+    "pretty_print_message",
+    "pretty_print_conversation",
+    "validate_message",
+    "validate_conversation",
+    "is_valid_message",
+    "is_valid_conversation",
+    "create_text_message",
+    "create_function_call",
+    "create_function_response",
+    "create_error_message",
+    "format_function_params",
+    "conversation_to_messages",
+    "skill",
+    "agent",
     # Workflow
-    'Flow',
-    'WorkflowContext',
-    'WorkflowStep',
-    'QueryStep',
-    'AutoRouteStep',
-    'FunctionStep',
-    'ConditionalBranch',
-    'ConditionStep',
-    'ParallelStep',
-    'ParallelBuilder',
-    'StepType',
-    
+    "Flow",
+    "WorkflowContext",
+    "WorkflowStep",
+    "QueryStep",
+    "AutoRouteStep",
+    "FunctionStep",
+    "ConditionalBranch",
+    "ConditionStep",
+    "ParallelStep",
+    "ParallelBuilder",
+    "StepType",
     # MCP
-    'MCPClient',
-    'MCPError', 
-    'MCPConnectionError',
-    'MCPTimeoutError',
-    'MCPToolError',
-    'MCPTools',
-    'MCPEnabledAgent',
-    'FastMCP',
-    'MCPResponse',
-    'text_response',
-    'error_response',
-    'image_response',
-    'multi_content_response',
-    'MCPContentType',
-    'FastMCPAgent',
-    'A2AMCPAgent',
-    'create_proxy_server',
-    'create_fastapi_app',
-    
+    "MCPClient",
+    "MCPError",
+    "MCPConnectionError",
+    "MCPTimeoutError",
+    "MCPToolError",
+    "MCPEnabledAgent",
+    "FastMCP",
+    "MCPResponse",
+    "text_response",
+    "error_response",
+    "image_response",
+    "multi_content_response",
+    "MCPContentType",
+    "FastMCPAgent",
+    "A2AMCPAgent",
+    "create_proxy_server",
+    "create_fastapi_app",
     # LangChain Integration (always included)
-    'to_a2a_server',
-    'to_langchain_agent',
-    'to_mcp_server',
-    'to_langchain_tool',
-    'LangChainIntegrationError',
-    'LangChainNotInstalledError',
-    'LangChainToolConversionError',
-    'MCPToolConversionError',
-    'LangChainAgentConversionError',
-    'A2AAgentConversionError',
+    "to_a2a_server",
+    "to_langchain_agent",
+    "to_mcp_server",
+    "to_langchain_tool",
+    "LangChainIntegrationError",
+    "LangChainNotInstalledError",
+    "LangChainToolConversionError",
+    "MCPToolConversionError",
+    "LangChainAgentConversionError",
+    "A2AAgentConversionError",
 ]
 
 # Conditionally add LLM clients/servers
 if HAS_LLM_CLIENTS:
-    __all__.extend(['OpenAIA2AClient', 'AnthropicA2AClient'])
+    __all__.extend(["OpenAIA2AClient", "OllamaA2AClient", "AnthropicA2AClient"])
 if HAS_LLM_SERVERS:
-    __all__.extend(['OpenAIA2AServer', 'AnthropicA2AServer', 'BedrockA2AServer'])
+    __all__.extend(
+        ["OpenAIA2AServer", "OllamaA2AServer", "AnthropicA2AServer", "BedrockA2AServer"]
+    )
 
 # Conditionally add docs
 if HAS_DOCS:
-    __all__.extend(['generate_a2a_docs', 'generate_html_docs'])
+    __all__.extend(["generate_a2a_docs", "generate_html_docs"])
 
 # Conditionally add CLI
 if HAS_CLI:
-    __all__.append('cli_main')
\ No newline at end of file
+    __all__.append("cli_main")
